/**
* @license Apache-2.0
*
* Copyright (c) 2022 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Transpose a matrix (or a stack of matrices).
*
* @module @stdlib/ndarray/base/transpose
*
* @example
* var array = require( '@stdlib/ndarray/array' );
* var transpose = require( '@stdlib/ndarray/base/transpose' );
*
* var x = array( [ [ 1, 2, 3 ], [ 4, 5, 6 ] ] );
* // returns <ndarray>
*
* var sh = x.shape;
* // returns [ 2, 3 ]
*
* var y = transpose( x );
* // returns <ndarray>
*
* sh = y.shape;
* // returns [ 3, 2 ]
*
* var bool = ( x.data === y.data );
* // returns true
*
* bool = ( x.get( 0, 1 ) === y.get( 1, 0 ) );
* // returns true
*/

// MODULES //

var main = require( './main.js' );


// EXPORTS //

module.exports = main;
